#!/usr/bin/env python3

import datetime
import pathlib
import sys
import sigmf
from sigmf.sigmffile import SigMFFile

files = pathlib.Path('.').glob('*.sigmf-data')
for f in files:
    filename = str(f).replace('.sigmf-data', '')
    timestamp = '2023-09-24T14:35:47.1399441528320312Z'
    antenna = {'0': '1a', '1': '5c'}[filename[-2]]
    polarization = filename[-1].upper()

    # create the metadata
    meta = SigMFFile(
        data_file = filename + '.sigmf-data', # extension is optional
        global_info = {
            SigMFFile.DATATYPE_KEY: 'ci16_le',
            SigMFFile.SAMPLE_RATE_KEY: 2048000,
            SigMFFile.AUTHOR_KEY: 'Daniel Estévez <daniel@destevez.net>',
            SigMFFile.DESCRIPTION_KEY: f'Recording of OSIRIS-REx with the Allen Telescope Array during SRC reentry',
            SigMFFile.VERSION_KEY: sigmf.__version__,
            SigMFFile.LICENSE_KEY: 'https://creativecommons.org/licenses/by/4.0/',
            SigMFFile.RECORDER_KEY: 'GNU Radio 3.10',
            SigMFFile.HW_KEY: (
                f'ATA antenna {antenna}, polarization {polarization}, LO d, USRP N321/N320'),
        }
    )

    # create a capture key at time index 0
    meta.add_capture(0, metadata={
        SigMFFile.FREQUENCY_KEY: 8445800000,
        SigMFFile.DATETIME_KEY: timestamp,
    })

    meta.tofile(filename + '.sigmf-meta') # extension is optional
